``argument-differ`` denotes an issue with the Liskov Substitution Principle.
This means that the code in question violates an important design principle which does not have
one single solution. We recommend to search online for the best solution in your case.

To give some examples of potential solutions:

* Add the argument to the parent class
* Remove the inheritance completely
* Add default arguments to the child class
